#!/bin/bash
# Author : Guth (guth@ploposor.com)
# URL : http://he.fi/bchunk/bchunk-1.2.0.tar.gz

# program name/version
FilenameFromUrl="$(grep 'U[R]L' $0 | rev | cut -d '/' -f1 | rev)"
softname="$(echo $FilenameFromUrl | cut -d '-' -f1)"
softversion="$(echo $FilenameFromUrl | cut -d '-' -f2 | cut -d '.' -f -3)"
#softversion='1.1.4'
#softname='bchunk'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='54.1'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"
srcpkg="$buildir/$FilenameFromUrl"

if ! [ -f "$FilenameFromUrl" ]; then
    echo "Downloading the program tarball...$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)"
    wget "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" ||exit 0
fi


# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest ||exit 0
rm -f $package.* ||exit 0
mkdir -p $dest/usr/{bin,man/man1} ||exit 0
mkdir -p $dest/install ||exit 0
mkdir -p $dest/usr/src/$softname-$softversion ||exit 0
mkdir -p $dest/usr/doc/$softname-$softversion ||exit 0

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
bchunk: bchunk BinChunker for Unix / Linux
bchunk:
bchunk: binchunker converts a CD image in a ".bin / .cue" format
bchunk: (sometimes ".raw / .cue") to a set of .iso and .cdr tracks.
bchunk: The bin/cue format is used by some popular non-Unix cd-writing
bchunk: software but is not supported on most other CD burning programs.
bchunk: 
bchunk: 
bchunk: 
bchunk: 
bchunk: 
EOF

# extract sources
echo "extracting ..."
srcdir="$softname-$softversion"
cd $buildir ||exit 0
rm -rf $srcdir ||exit 0
tar zxf $srcdir.tar.gz ||exit 0
cd $srcdir ||exit 0

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

sed -i "s@/usr/local@$dest/usr@g" Makefile

# compile package
make $ntasks ||exit 0

# install package to the target directory
make install DESTDIR=$dest ||exit 0

# copy the doc files

cp -a \
 COPYING ChangeLog README \
 $dest/usr/doc/$softname-$softversion ||exit 0

# strip executables
echo "stripping ..."
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# gzip man pages and info files
echo "gzipping ..."
gzip -9 $dest/usr/man/*/*
chown -R root.root $dest/usr/man/*/*


# put the ZenWalk build and other needed files in the right directory
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion ||exit 0
chown -R root.root $dest/usr/src/$softname-$softversion ||exit 0

# change files ownerships for $dest/usr/sbin
chown -R root.root $dest/usr/bin ||exit 0

# make the package and move it to the build directory

#------------------( Create The *.dep File )
echo "creating .dep ..."
cd $dest
requiredbuilder -z $dest > $buildir/$package.dep ||exit 0
#echo -n "attr,bzip2,cyrus-sasl,e2fsprogs,glibc,krb5,libcap,libmysqlclient,openldap-client,openssl,pam,samba,zlib" > $buildir/$package.dep ||exit 0

cd $dest
/sbin/makepkg -l y -c n $package.tgz ||exit 0
mv $package.tgz $buildir ||exit 0

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir ||exit 0
md5sum $package.tgz > $package.md5 ||exit 0

echo "glibc" > $package.dep

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

echo "$(grep 'U[R]L' $0 | rev | cut -d ' ' -f1 | cut -d "	" -f 1 | rev)" > $package.src
echo "http://zen-repo.meticul.eu/zen_stuffs/guth/packages/bchunk/build-bchunk.sh" >> $package.src
